import pyhausbus.HausBusUtils as HausBusUtils

class MinBrightness:
  CLASS_ID = 21
  FUNCTION_ID = 130

  def __init__(self,minBrightness:int):
    self.minBrightness=minBrightness


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return MinBrightness(HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"MinBrightness(minBrightness={self.minBrightness})"

  '''
  @param minBrightness Eine ausgeschaltete LED leuchtet immer noch mit dieser Helligkeit 0-100%.
  '''
  def getMinBrightness(self):
    return self.minBrightness






from pyhausbus.de.hausbus.homeassistant.proxy.feuchtesensor.params.ELastEvent import ELastEvent
import pyhausbus.HausBusUtils as HausBusUtils

class Status:
  CLASS_ID = 34
  FUNCTION_ID = 129

  def __init__(self,relativeHumidity:int, centiHumidity:int, lastEvent:ELastEvent):
    self.relativeHumidity=relativeHumidity
    self.centiHumidity=centiHumidity
    self.lastEvent=lastEvent


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Status(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), ELastEvent._fromBytes(dataIn, offset))

  def __str__(self):
    return f"Status(relativeHumidity={self.relativeHumidity}, centiHumidity={self.centiHumidity}, lastEvent={self.lastEvent})"

  '''
  @param relativeHumidity Relative Luftfeuchte in %.
  '''
  def getRelativeHumidity(self):
    return self.relativeHumidity

  '''
  @param centiHumidity hundertstel Relative Luftfeuchte in %.
  '''
  def getCentiHumidity(self):
    return self.centiHumidity

  '''
  @param lastEvent .
  '''
  def getLastEvent(self):
    return self.lastEvent






from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EReason import EReason
import pyhausbus.HausBusUtils as HausBusUtils

class EvStarted:
  CLASS_ID = 0
  FUNCTION_ID = 202

  def __init__(self,reason:EReason):
    self.reason=reason


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvStarted(EReason._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvStarted(reason={self.reason})"

  '''
  @param reason Grund fuer dieses Event.
  '''
  def getReason(self):
    return self.reason






import pyhausbus.HausBusUtils as HausBusUtils

class ConnectedDevices:
  CLASS_ID = 176
  FUNCTION_ID = 130

  def __init__(self,deviceIds):
    self.deviceIds=deviceIds


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return ConnectedDevices(HausBusUtils.bytesToList(dataIn, offset))

  def __str__(self):
    return f"ConnectedDevices(deviceIds={self.deviceIds})"

  '''
  @param deviceIds .
  '''
  def getDeviceIds(self):
    return self.deviceIds






import pyhausbus.HausBusUtils as HausBusUtils

class SetWatchDogTime:
  CLASS_ID = 0
  FUNCTION_ID = 21

  def __init__(self,time:int):
    self.time=time


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetWatchDogTime(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"SetWatchDogTime(time={self.time})"

  '''
  @param time Zeit in Sekunden bis zum Reset wenn kein Ping empfangen wird. 0 deativiert den WatchDog.
  '''
  def getTime(self):
    return self.time






import pyhausbus.HausBusUtils as HausBusUtils

class Pong:
  CLASS_ID = 0
  FUNCTION_ID = 199

  def __init__(self,watchDogTime:int):
    self.watchDogTime=watchDogTime


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Pong(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"Pong(watchDogTime={self.watchDogTime})"

  '''
  @param watchDogTime Verbleibende Zeit in Sekunden bis zum Watchdog Reset.
  '''
  def getWatchDogTime(self):
    return self.watchDogTime






from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.tcpClient.data.CurrentIp import CurrentIp

class TcpClient(ABusFeature):
  CLASS_ID:int = 91

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return TcpClient(HausBusUtils.getObjectId(deviceId, 91, instanceId))

  """
  @param IP0 .
  @param IP1 .
  @param IP2 .
  @param IP3 .
  @param port .
  """
  def announceServer(self, IP0:int, IP1:int, IP2:int, IP3:int, port:int):
    LOGGER.debug("announceServer"+" IP0 = "+str(IP0)+" IP1 = "+str(IP1)+" IP2 = "+str(IP2)+" IP3 = "+str(IP3)+" port = "+str(port))
    hbCommand = HausBusCommand(self.objectId, 1, "announceServer")
    hbCommand.addByte(IP0)
    hbCommand.addByte(IP1)
    hbCommand.addByte(IP2)
    hbCommand.addByte(IP3)
    hbCommand.addWord(port)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getCurrentIp(self):
    LOGGER.debug("getCurrentIp")
    hbCommand = HausBusCommand(self.objectId, 2, "getCurrentIp")
    ResultWorker()._setResultInfo(CurrentIp,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param IP0 .
  @param IP1 .
  @param IP2 .
  @param IP3 .
  """
  def CurrentIp(self, IP0:int, IP1:int, IP2:int, IP3:int):
    LOGGER.debug("CurrentIp"+" IP0 = "+str(IP0)+" IP1 = "+str(IP1)+" IP2 = "+str(IP2)+" IP3 = "+str(IP3))
    hbCommand = HausBusCommand(self.objectId, 128, "CurrentIp")
    hbCommand.addByte(IP0)
    hbCommand.addByte(IP1)
    hbCommand.addByte(IP2)
    hbCommand.addByte(IP3)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evWhoIsServer(self):
    LOGGER.debug("evWhoIsServer")
    hbCommand = HausBusCommand(self.objectId, 200, "evWhoIsServer")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils

class EvDisabled:
  CLASS_ID = 19
  FUNCTION_ID = 204

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvDisabled()

  def __str__(self):
    return f"EvDisabled()"






import pyhausbus.HausBusUtils as HausBusUtils

class SetColor:
  CLASS_ID = 22
  FUNCTION_ID = 2

  def __init__(self,brightnessRed:int, brightnessGreen:int, brightnessBlue:int, duration:int):
    self.brightnessRed=brightnessRed
    self.brightnessGreen=brightnessGreen
    self.brightnessBlue=brightnessBlue
    self.duration=duration


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetColor(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"SetColor(brightnessRed={self.brightnessRed}, brightnessGreen={self.brightnessGreen}, brightnessBlue={self.brightnessBlue}, duration={self.duration})"

  '''
  @param brightnessRed Helligkeit ROT-Anteil. \r\n0: AUS\r\n100: MAX.
  '''
  def getBrightnessRed(self):
    return self.brightnessRed

  '''
  @param brightnessGreen Helligkeit GRUEN-Anteil. \r\n0: AUS\r\n100: MAX.
  '''
  def getBrightnessGreen(self):
    return self.brightnessGreen

  '''
  @param brightnessBlue Helligkeit BLAU-Anteil. \r\n0: AUS\r\n100: MAX.
  '''
  def getBrightnessBlue(self):
    return self.brightnessBlue

  '''
  @param duration Einschaltdauer in Sekunden.
  '''
  def getDuration(self):
    return self.duration






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class EWeekDay(Enum):
  Monday=1
  Tuesday=2
  Wednesday=3
  Thursday=4
  Friday=5
  Saturday=6
  Sunday=7
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in EWeekDay.__members__.values():
      if (act.value == checkValue):
        return act

    return EWeekDay.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'EWeekDay':
    try:
      return EWeekDay[name]
    except KeyError:
      return EWeekDay.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils

class CurrentIp:
  CLASS_ID = 164
  FUNCTION_ID = 129

  def __init__(self,IP0:int, IP1:int, IP2:int, IP3:int):
    self.IP0=IP0
    self.IP1=IP1
    self.IP2=IP2
    self.IP3=IP3


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return CurrentIp(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"CurrentIp({self.IP0}.{self.IP1}.{self.IP2}.{self.IP3})"

  '''
  @param IP0 .
  '''
  def getIP0(self):
    return self.IP0

  '''
  @param IP1 .
  '''
  def getIP1(self):
    return self.IP1

  '''
  @param IP2 .
  '''
  def getIP2(self):
    return self.IP2

  '''
  @param IP3 .
  '''
  def getIP3(self):
    return self.IP3






from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.params.ESensorType import ESensorType
import pyhausbus.HausBusUtils as HausBusUtils

class Configuration:
  CLASS_ID = 45
  FUNCTION_ID = 128

  def __init__(self,idx:int, node:int, sensorType:ESensorType):
    self.idx=idx
    self.node=node
    self.sensorType=sensorType


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Configuration(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), ESensorType._fromBytes(dataIn, offset))

  def __str__(self):
    return f"Configuration(idx={self.idx}, node={self.node}, sensorType={self.sensorType})"

  '''
  @param idx index of the configuration slot.
  '''
  def getIdx(self):
    return self.idx

  '''
  @param node device node on ModBus.
  '''
  def getNode(self):
    return self.node

  '''
  @param sensorType Supported Power-Meter SDM630 / SDM72D / SDM72V2 / ORWE517.
  '''
  def getSensorType(self):
    return self.sensorType






import pyhausbus.HausBusUtils as HausBusUtils

class ResetOneWireManager:
  CLASS_ID = 0
  FUNCTION_ID = 20

  def __init__(self,index:int):
    self.index=index


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return ResetOneWireManager(HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"ResetOneWireManager(index={self.index})"

  '''
  @param index 0: loescht alle OneWire Sensor Positionen\r\n1-32: loescht nur den Sensor auf der Position.
  '''
  def getIndex(self):
    return self.index






import pyhausbus.HausBusUtils as HausBusUtils

class GetCurrent:
  CLASS_ID = 90
  FUNCTION_ID = 1

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetCurrent()

  def __str__(self):
    return f"GetCurrent()"






import pyhausbus.HausBusUtils as HausBusUtils

class RuleState:
  CLASS_ID = 0
  FUNCTION_ID = 135

  def __init__(self,index:int, state:int):
    self.index=index
    self.state=state


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return RuleState(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"RuleState(index={self.index}, state={self.state})"

  '''
  @param index Index der abgefragten Regel.
  '''
  def getIndex(self):
    return self.index

  '''
  @param state Regelzustand.
  '''
  def getState(self):
    return self.state






import pyhausbus.HausBusUtils as HausBusUtils

class EvDark:
  CLASS_ID = 39
  FUNCTION_ID = 200

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvDark()

  def __str__(self):
    return f"EvDark()"






import pyhausbus.HausBusUtils as HausBusUtils

class IncSignalCount:
  CLASS_ID = 90
  FUNCTION_ID = 9

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return IncSignalCount()

  def __str__(self):
    return f"IncSignalCount()"






import pyhausbus.HausBusUtils as HausBusUtils

class GetStatus:
  CLASS_ID = 21
  FUNCTION_ID = 5

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetStatus()

  def __str__(self):
    return f"GetStatus()"






from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.ModuleId import ModuleId
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EIndex import EIndex
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EFirmwareId import EFirmwareId
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.MLogicalButtonMask import MLogicalButtonMask
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.ESlotType import ESlotType
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.RemoteObjects import RemoteObjects
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.UnusedMemory import UnusedMemory
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.MemoryData import MemoryData
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.MemoryStatus import MemoryStatus
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.Pong import Pong
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EStatus import EStatus
from pyhausbus.WeekTime import WeekTime
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EReason import EReason
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EErrorCode import EErrorCode
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.Time import Time
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.RuleState import RuleState
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.MOption import MOption
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EType import EType
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.SystemVariable import SystemVariable
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.UnitGroupStatus import UnitGroupStatus
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EFeatureId import EFeatureId

class Controller(ABusFeature):
  CLASS_ID:int = 0

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return Controller(HausBusUtils.getObjectId(deviceId, 0, instanceId))

  """
  @param index .
  """
  def getModuleId(self, index:EIndex):
    LOGGER.debug("getModuleId"+" index = "+str(index))
    hbCommand = HausBusCommand(self.objectId, 2, "getModuleId")
    hbCommand.addByte(index.value)
    ResultWorker()._setResultInfo(ModuleId,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 5, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param name Modulname.
  @param size Modulgroesse in Bytes.
  @param majorRelease Release-Kennung Format major.minor.
  @param minorRelease Release-Kennung Format major.minor.
  @param firmwareId Firmware-Kennung.
  """
  def ModuleId(self, name:str, size:int, majorRelease:int, minorRelease:int, firmwareId:EFirmwareId):
    LOGGER.debug("ModuleId"+" name = "+str(name)+" size = "+str(size)+" majorRelease = "+str(majorRelease)+" minorRelease = "+str(minorRelease)+" firmwareId = "+str(firmwareId))
    hbCommand = HausBusCommand(self.objectId, 128, "ModuleId")
    hbCommand.addString(name)
    hbCommand.addDWord(size)
    hbCommand.addByte(majorRelease)
    hbCommand.addByte(minorRelease)
    hbCommand.addByte(firmwareId.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param startupDelay a 250ms.
  @param logicalButtonMask jedes Bit enspricht einem logischem Taster.
  @param deviceId .
  @param reportMemoryStatusTime Zeitinterval in Minuten1-255min.
  @param slotType0 .
  @param slotType1 .
  @param slotType2 .
  @param slotType3 .
  @param slotType4 .
  @param slotType5 .
  @param slotType6 .
  @param slotType7 .
  @param timeCorrection Korregiert den internen Zeitgeber um diesen Wert pro Minute.
  @param reserve .
  @param dataBlockSize maximale Groesse des Datenblocks in einer Nachricht.
  @param FCKE ControllerBoard Version Bsp. 30 = v3.0.
  """
  def Configuration(self, startupDelay:int, logicalButtonMask:MLogicalButtonMask, deviceId:int, reportMemoryStatusTime:int, slotType0:ESlotType, slotType1:ESlotType, slotType2:ESlotType, slotType3:ESlotType, slotType4:ESlotType, slotType5:ESlotType, slotType6:ESlotType, slotType7:ESlotType, timeCorrection:int, reserve:int, dataBlockSize:int, FCKE:int):
    LOGGER.debug("Configuration"+" startupDelay = "+str(startupDelay)+" logicalButtonMask = "+str(logicalButtonMask)+" deviceId = "+str(deviceId)+" reportMemoryStatusTime = "+str(reportMemoryStatusTime)+" slotType0 = "+str(slotType0)+" slotType1 = "+str(slotType1)+" slotType2 = "+str(slotType2)+" slotType3 = "+str(slotType3)+" slotType4 = "+str(slotType4)+" slotType5 = "+str(slotType5)+" slotType6 = "+str(slotType6)+" slotType7 = "+str(slotType7)+" timeCorrection = "+str(timeCorrection)+" reserve = "+str(reserve)+" dataBlockSize = "+str(dataBlockSize)+" FCKE = "+str(FCKE))
    hbCommand = HausBusCommand(self.objectId, 131, "Configuration")
    hbCommand.addByte(startupDelay)
    hbCommand.addByte(logicalButtonMask.getValue())
    hbCommand.addWord(deviceId)
    hbCommand.addByte(reportMemoryStatusTime)
    hbCommand.addByte(slotType0.value)
    hbCommand.addByte(slotType1.value)
    hbCommand.addByte(slotType2.value)
    hbCommand.addByte(slotType3.value)
    hbCommand.addByte(slotType4.value)
    hbCommand.addByte(slotType5.value)
    hbCommand.addByte(slotType6.value)
    hbCommand.addByte(slotType7.value)
    hbCommand.addByte(timeCorrection)
    hbCommand.addWord(reserve)
    hbCommand.addWord(dataBlockSize)
    hbCommand.addByte(FCKE)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getRemoteObjects(self):
    LOGGER.debug("getRemoteObjects")
    hbCommand = HausBusCommand(self.objectId, 3, "getRemoteObjects")
    ResultWorker()._setResultInfo(RemoteObjects,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param objectList Eine Liste der Verfuegbaren Objekte im Geraete.
  """
  def RemoteObjects(self, objectList):
    LOGGER.debug("RemoteObjects"+" objectList = "+str(objectList))
    hbCommand = HausBusCommand(self.objectId, 129, "RemoteObjects")
    hbCommand.addMap(objectList)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def generateRandomDeviceId(self):
    LOGGER.debug("generateRandomDeviceId")
    hbCommand = HausBusCommand(self.objectId, 0, "generateRandomDeviceId")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def reset(self):
    LOGGER.debug("reset")
    hbCommand = HausBusCommand(self.objectId, 1, "reset")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getUnusedMemory(self):
    LOGGER.debug("getUnusedMemory")
    hbCommand = HausBusCommand(self.objectId, 4, "getUnusedMemory")
    ResultWorker()._setResultInfo(UnusedMemory,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param startupDelay a 10ms.
  @param logicalButtonMask jedes Bit enspricht einem logischem Taster.
  @param deviceId .
  @param reportMemoryStatusTime Zeitinterval in Minuten1-255min.
  @param slotType0 .
  @param slotType1 .
  @param slotType2 .
  @param slotType3 .
  @param slotType4 .
  @param slotType5 .
  @param slotType6 .
  @param slotType7 .
  """
  def setConfiguration(self, startupDelay:int, logicalButtonMask:MLogicalButtonMask, deviceId:int, reportMemoryStatusTime:int, slotType0:ESlotType, slotType1:ESlotType, slotType2:ESlotType, slotType3:ESlotType, slotType4:ESlotType, slotType5:ESlotType, slotType6:ESlotType, slotType7:ESlotType):
    LOGGER.debug("setConfiguration"+" startupDelay = "+str(startupDelay)+" logicalButtonMask = "+str(logicalButtonMask)+" deviceId = "+str(deviceId)+" reportMemoryStatusTime = "+str(reportMemoryStatusTime)+" slotType0 = "+str(slotType0)+" slotType1 = "+str(slotType1)+" slotType2 = "+str(slotType2)+" slotType3 = "+str(slotType3)+" slotType4 = "+str(slotType4)+" slotType5 = "+str(slotType5)+" slotType6 = "+str(slotType6)+" slotType7 = "+str(slotType7))
    hbCommand = HausBusCommand(self.objectId, 6, "setConfiguration")
    hbCommand.addByte(startupDelay)
    hbCommand.addByte(logicalButtonMask.getValue())
    hbCommand.addWord(deviceId)
    hbCommand.addByte(reportMemoryStatusTime)
    hbCommand.addByte(slotType0.value)
    hbCommand.addByte(slotType1.value)
    hbCommand.addByte(slotType2.value)
    hbCommand.addByte(slotType3.value)
    hbCommand.addByte(slotType4.value)
    hbCommand.addByte(slotType5.value)
    hbCommand.addByte(slotType6.value)
    hbCommand.addByte(slotType7.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param freeStack Anzahl des nicht genutzten Stacks in Bytes..
  @param freeHeap Aktuell freier Heap in Bytes..
  """
  def UnusedMemory(self, freeStack:int, freeHeap:int):
    LOGGER.debug("UnusedMemory"+" freeStack = "+str(freeStack)+" freeHeap = "+str(freeHeap))
    hbCommand = HausBusCommand(self.objectId, 130, "UnusedMemory")
    hbCommand.addWord(freeStack)
    hbCommand.addWord(freeHeap)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address .
  @param length .
  """
  def readMemory(self, address:int, length:int):
    LOGGER.debug("readMemory"+" address = "+str(address)+" length = "+str(length))
    hbCommand = HausBusCommand(self.objectId, 7, "readMemory")
    hbCommand.addDWord(address)
    hbCommand.addWord(length)
    ResultWorker()._setResultInfo(MemoryData,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address .
  @param data .
  """
  def writeMemory(self, address:int, data:bytearray):
    LOGGER.debug("writeMemory"+" address = "+str(address)+" data = "+str(data))
    hbCommand = HausBusCommand(self.objectId, 8, "writeMemory")
    hbCommand.addDWord(address)
    hbCommand.addBlob(data)
    ResultWorker()._setResultInfo(MemoryStatus,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def ping(self):
    LOGGER.debug("ping")
    hbCommand = HausBusCommand(self.objectId, 127, "ping")
    ResultWorker()._setResultInfo(Pong,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param watchDogTime Verbleibende Zeit in Sekunden bis zum Watchdog Reset.
  """
  def pong(self, watchDogTime:int):
    LOGGER.debug("pong"+" watchDogTime = "+str(watchDogTime))
    hbCommand = HausBusCommand(self.objectId, 199, "pong")
    hbCommand.addWord(watchDogTime)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address Adresse des gemeldeten Speicherinhaltes.
  @param data Daten....
  """
  def MemoryData(self, address:int, data:bytearray):
    LOGGER.debug("MemoryData"+" address = "+str(address)+" data = "+str(data))
    hbCommand = HausBusCommand(self.objectId, 132, "MemoryData")
    hbCommand.addDWord(address)
    hbCommand.addBlob(data)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param status Status des letzten Speicherzugriffs.
  @param address Speicheradresse zu dem dieser Status gesendet wird..
  """
  def MemoryStatus(self, status:EStatus, address:int):
    LOGGER.debug("MemoryStatus"+" status = "+str(status)+" address = "+str(address))
    hbCommand = HausBusCommand(self.objectId, 133, "MemoryStatus")
    hbCommand.addByte(status.value)
    hbCommand.addDWord(address)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param offset aktueller Offset im Gesamtregelblock.
  @param data .
  """
  def writeRules(self, offset:int, data:bytearray):
    LOGGER.debug("writeRules"+" offset = "+str(offset)+" data = "+str(data))
    hbCommand = HausBusCommand(self.objectId, 9, "writeRules")
    hbCommand.addWord(offset)
    hbCommand.addBlob(data)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param offset Offset im Gesamtregelblock.
  @param length Datenlaenge.
  """
  def readRules(self, offset:int, length:int):
    LOGGER.debug("readRules"+" offset = "+str(offset)+" length = "+str(length))
    hbCommand = HausBusCommand(self.objectId, 10, "readRules")
    hbCommand.addWord(offset)
    hbCommand.addWord(length)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param offset offset im Gesamtregelblock.
  @param data .
  """
  def RulesData(self, offset:int, data:bytearray):
    LOGGER.debug("RulesData"+" offset = "+str(offset)+" data = "+str(data))
    hbCommand = HausBusCommand(self.objectId, 134, "RulesData")
    hbCommand.addWord(offset)
    hbCommand.addBlob(data)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param weektime .
  """
  def evTime(self, weektime:WeekTime=None
):
    LOGGER.debug("evTime"+" weektime = "+str(weektime))
    hbCommand = HausBusCommand(self.objectId, 200, "evTime")
    hbCommand.addWord(weektime.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param deviceId neue ID.
  """
  def evNewDeviceId(self, deviceId:int):
    LOGGER.debug("evNewDeviceId"+" deviceId = "+str(deviceId))
    hbCommand = HausBusCommand(self.objectId, 201, "evNewDeviceId")
    hbCommand.addWord(deviceId)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param reason Grund fuer dieses Event.
  """
  def evStarted(self, reason:EReason):
    LOGGER.debug("evStarted"+" reason = "+str(reason))
    hbCommand = HausBusCommand(self.objectId, 202, "evStarted")
    hbCommand.addByte(reason.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getTime(self):
    LOGGER.debug("getTime")
    hbCommand = HausBusCommand(self.objectId, 126, "getTime")
    ResultWorker()._setResultInfo(Time,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param weekTime .
  """
  def setTime(self, weekTime:WeekTime=None
):
    LOGGER.debug("setTime"+" weekTime = "+str(weekTime))
    hbCommand = HausBusCommand(self.objectId, 125, "setTime")
    hbCommand.addWord(weekTime.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param weekTime .
  """
  def Time(self, weekTime:WeekTime=None
):
    LOGGER.debug("Time"+" weekTime = "+str(weekTime))
    hbCommand = HausBusCommand(self.objectId, 198, "Time")
    hbCommand.addWord(weekTime.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Index des abzufragenden Regelzustandes auf dem Controller.
  """
  def getRuleState(self, index:int):
    LOGGER.debug("getRuleState"+" index = "+str(index))
    hbCommand = HausBusCommand(self.objectId, 12, "getRuleState")
    hbCommand.addByte(index)
    ResultWorker()._setResultInfo(RuleState,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Index des zu setzenden Regelzustandes auf dem Controller..
  @param state Der Zustand wird gesetzt ohne die Aktionen auszufuehren..
  """
  def setRuleState(self, index:int, state:int):
    LOGGER.debug("setRuleState"+" index = "+str(index)+" state = "+str(state))
    hbCommand = HausBusCommand(self.objectId, 11, "setRuleState")
    hbCommand.addByte(index)
    hbCommand.addByte(state)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param indexRule Index der Regel im Controller..
  @param indexElement Index des auszufuehrenden Regelelementes. Alle Aktionen werden ausgefuehrt und der neue Zustand eingenommen..
  """
  def triggerRuleElement(self, indexRule:int, indexElement:int):
    LOGGER.debug("triggerRuleElement"+" indexRule = "+str(indexRule)+" indexElement = "+str(indexElement))
    hbCommand = HausBusCommand(self.objectId, 13, "triggerRuleElement")
    hbCommand.addByte(indexRule)
    hbCommand.addByte(indexElement)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Index der abgefragten Regel.
  @param state Regelzustand.
  """
  def RuleState(self, index:int, state:int):
    LOGGER.debug("RuleState"+" index = "+str(index)+" state = "+str(state))
    hbCommand = HausBusCommand(self.objectId, 135, "RuleState")
    hbCommand.addByte(index)
    hbCommand.addByte(state)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Gruppenindex.
  @param member Gruppenteilnehmer 0-15.
  @param state Zustand des Teilnehmers 0=AUS.
  @param triggerBits Anzahl der Teilnehmer die gesetzt sein muessen damit evGroupOn erzeugt wird.
  """
  def setUnitGroupState(self, index:int, member:int, state:int, triggerBits:int):
    LOGGER.debug("setUnitGroupState"+" index = "+str(index)+" member = "+str(member)+" state = "+str(state)+" triggerBits = "+str(triggerBits))
    hbCommand = HausBusCommand(self.objectId, 14, "setUnitGroupState")
    hbCommand.addByte(index)
    hbCommand.addByte(member)
    hbCommand.addByte(state)
    hbCommand.addByte(triggerBits)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Gruppenindex.
  @param status Status der Bits in der logischen Gruppe..
  """
  def evGroupOn(self, index:int, status:int):
    LOGGER.debug("evGroupOn"+" index = "+str(index)+" status = "+str(status))
    hbCommand = HausBusCommand(self.objectId, 203, "evGroupOn")
    hbCommand.addByte(index)
    hbCommand.addWord(status)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Gruppenindex.
  @param status Status der Bits in der logischen Gruppe..
  """
  def evGroupOff(self, index:int, status:int):
    LOGGER.debug("evGroupOff"+" index = "+str(index)+" status = "+str(status))
    hbCommand = HausBusCommand(self.objectId, 205, "evGroupOff")
    hbCommand.addByte(index)
    hbCommand.addWord(status)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Gruppenindex.
  @param status Status der Bits in der logischen Gruppe..
  """
  def evGroupUndefined(self, index:int, status:int):
    LOGGER.debug("evGroupUndefined"+" index = "+str(index)+" status = "+str(status))
    hbCommand = HausBusCommand(self.objectId, 204, "evGroupUndefined")
    hbCommand.addByte(index)
    hbCommand.addWord(status)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param ruleIndex .
  @param elementIndex .
  """
  def TriggeredRule(self, ruleIndex:int, elementIndex:int):
    LOGGER.debug("TriggeredRule"+" ruleIndex = "+str(ruleIndex)+" elementIndex = "+str(elementIndex))
    hbCommand = HausBusCommand(self.objectId, 136, "TriggeredRule")
    hbCommand.addByte(ruleIndex)
    hbCommand.addByte(elementIndex)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param option SEND_TRIGGERED_RULE_EVENT: generiert ein Event zu einer aktivierten Regel\r\nREAD_ONLY_GATEWAYS: schaltet das Versenden saemtlicher Nachrichten ab. Eingehende Nachrichten werden verarbeitet\r\nREPORT_INTERNAL_TEMPERATURE: aktiviert den internen TemperaturSensor des Prozessors ungenau\r\nSEND_ZERO_CROSS_DATA: sendet im Sekundentakt aufgezeichnete Daten zur Nulldurchganserkennung bei Dimmer-Modulen.
  """
  def setDebugOptions(self, option:MOption):
    LOGGER.debug("setDebugOptions"+" option = "+str(option))
    hbCommand = HausBusCommand(self.objectId, 124, "setDebugOptions")
    hbCommand.addByte(option.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param timeDifference Abweichung der internen Wochenzeit in Minuten Achtung: Vorzeichenbehaftetes Byte. 255 entspricht -1.
  """
  def TimeDifference(self, timeDifference:int):
    LOGGER.debug("TimeDifference"+" timeDifference = "+str(timeDifference))
    hbCommand = HausBusCommand(self.objectId, 197, "TimeDifference")
    hbCommand.addByte(timeDifference)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evDay(self):
    LOGGER.debug("evDay")
    hbCommand = HausBusCommand(self.objectId, 206, "evDay")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evNight(self):
    LOGGER.debug("evNight")
    hbCommand = HausBusCommand(self.objectId, 207, "evNight")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param sunriseTime Zeit fuer den Sonnenaufgang..
  @param sunsetTime Zeit fuer den Sonnenuntergang..
  """
  def setSunTimes(self, sunriseTime:WeekTime=None
, sunsetTime:WeekTime=None
):
    LOGGER.debug("setSunTimes"+" sunriseTime = "+str(sunriseTime)+" sunsetTime = "+str(sunsetTime))
    hbCommand = HausBusCommand(self.objectId, 15, "setSunTimes")
    hbCommand.addWord(sunriseTime.getValue())
    hbCommand.addWord(sunsetTime.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param type Hier wird der Typ der Variable.
  @param index Die Variablen liegen mehrfach vor 32xBIT.
  @param value Die Systemvariable wird mit diesem Wert belegt..
  """
  def setSystemVariable(self, type:EType, index:int, value:int):
    LOGGER.debug("setSystemVariable"+" type = "+str(type)+" index = "+str(index)+" value = "+str(value))
    hbCommand = HausBusCommand(self.objectId, 16, "setSystemVariable")
    hbCommand.addByte(type.value)
    hbCommand.addByte(index)
    hbCommand.addWord(value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param type Hier wird der Typ der Variable.
  @param index Die Variablen liegen mehrfach vor 32xBIT.
  """
  def getSystemVariable(self, type:EType, index:int):
    LOGGER.debug("getSystemVariable"+" type = "+str(type)+" index = "+str(index))
    hbCommand = HausBusCommand(self.objectId, 17, "getSystemVariable")
    hbCommand.addByte(type.value)
    hbCommand.addByte(index)
    ResultWorker()._setResultInfo(SystemVariable,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param type Gibt den Typ der Variable an.
  @param index Die Variablen liegen mehrfach vor 32xBIT.
  @param value Der Wert der Systemvariable..
  """
  def SystemVariable(self, type:EType, index:int, value:int):
    LOGGER.debug("SystemVariable"+" type = "+str(type)+" index = "+str(index)+" value = "+str(value))
    hbCommand = HausBusCommand(self.objectId, 137, "SystemVariable")
    hbCommand.addByte(type.value)
    hbCommand.addByte(index)
    hbCommand.addWord(value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Index der logischen Gruppe in diesem Controller.
  """
  def getUnitGroupStatus(self, index:int):
    LOGGER.debug("getUnitGroupStatus"+" index = "+str(index))
    hbCommand = HausBusCommand(self.objectId, 18, "getUnitGroupStatus")
    hbCommand.addByte(index)
    ResultWorker()._setResultInfo(UnitGroupStatus,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index Index der logischen Gruppe in diesem Controller.
  @param status Status der Bits in der logischen Gruppe..
  """
  def UnitGroupStatus(self, index:int, status:int):
    LOGGER.debug("UnitGroupStatus"+" index = "+str(index)+" status = "+str(status))
    hbCommand = HausBusCommand(self.objectId, 138, "UnitGroupStatus")
    hbCommand.addByte(index)
    hbCommand.addWord(status)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param consoleString Debug Ausgaben bei spezieller Firmware zur Fehlersuche.
  """
  def evConsole(self, consoleString:str):
    LOGGER.debug("evConsole"+" consoleString = "+str(consoleString))
    hbCommand = HausBusCommand(self.objectId, 250, "evConsole")
    hbCommand.addString(consoleString)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evResetWifi(self):
    LOGGER.debug("evResetWifi")
    hbCommand = HausBusCommand(self.objectId, 208, "evResetWifi")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param channel PWM-Kanal.
  @param pulseCount Anzahl der guten Pulse innerhalb der letzten Messperiode 1s.
  @param deltaTime Falls Messperiode l?nger als 1s ist.
  @param lowTime0 .
  @param lowTime1 .
  @param lowTime2 .
  @param lowTime3 .
  @param lowTime4 .
  @param lowTime5 .
  @param lowTime6 .
  @param lowTime7 .
  @param lowTime8 .
  @param lowTime9 .
  @param lowTime10 .
  @param lowTime11 .
  @param lowTime12 .
  @param lowTime13 .
  @param lowTime14 .
  @param lowTime15 .
  @param pulsWidth0 .
  @param pulsWidth1 .
  @param pulsWidth2 .
  @param pulsWidth3 .
  @param pulsWidth4 .
  @param pulsWidth5 .
  @param pulsWidth6 .
  @param pulsWidth7 .
  @param pulsWidth8 .
  @param pulsWidth9 .
  @param pulsWidth10 .
  @param pulsWidth11 .
  @param pulsWidth12 .
  @param pulsWidth13 .
  @param pulsWidth14 .
  @param pulsWidth15 .
  """
  def evZeroCrossData(self, channel:int, pulseCount:int, deltaTime:int, lowTime0:int, lowTime1:int, lowTime2:int, lowTime3:int, lowTime4:int, lowTime5:int, lowTime6:int, lowTime7:int, lowTime8:int, lowTime9:int, lowTime10:int, lowTime11:int, lowTime12:int, lowTime13:int, lowTime14:int, lowTime15:int, pulsWidth0:int, pulsWidth1:int, pulsWidth2:int, pulsWidth3:int, pulsWidth4:int, pulsWidth5:int, pulsWidth6:int, pulsWidth7:int, pulsWidth8:int, pulsWidth9:int, pulsWidth10:int, pulsWidth11:int, pulsWidth12:int, pulsWidth13:int, pulsWidth14:int, pulsWidth15:int):
    LOGGER.debug("evZeroCrossData"+" channel = "+str(channel)+" pulseCount = "+str(pulseCount)+" deltaTime = "+str(deltaTime)+" lowTime0 = "+str(lowTime0)+" lowTime1 = "+str(lowTime1)+" lowTime2 = "+str(lowTime2)+" lowTime3 = "+str(lowTime3)+" lowTime4 = "+str(lowTime4)+" lowTime5 = "+str(lowTime5)+" lowTime6 = "+str(lowTime6)+" lowTime7 = "+str(lowTime7)+" lowTime8 = "+str(lowTime8)+" lowTime9 = "+str(lowTime9)+" lowTime10 = "+str(lowTime10)+" lowTime11 = "+str(lowTime11)+" lowTime12 = "+str(lowTime12)+" lowTime13 = "+str(lowTime13)+" lowTime14 = "+str(lowTime14)+" lowTime15 = "+str(lowTime15)+" pulsWidth0 = "+str(pulsWidth0)+" pulsWidth1 = "+str(pulsWidth1)+" pulsWidth2 = "+str(pulsWidth2)+" pulsWidth3 = "+str(pulsWidth3)+" pulsWidth4 = "+str(pulsWidth4)+" pulsWidth5 = "+str(pulsWidth5)+" pulsWidth6 = "+str(pulsWidth6)+" pulsWidth7 = "+str(pulsWidth7)+" pulsWidth8 = "+str(pulsWidth8)+" pulsWidth9 = "+str(pulsWidth9)+" pulsWidth10 = "+str(pulsWidth10)+" pulsWidth11 = "+str(pulsWidth11)+" pulsWidth12 = "+str(pulsWidth12)+" pulsWidth13 = "+str(pulsWidth13)+" pulsWidth14 = "+str(pulsWidth14)+" pulsWidth15 = "+str(pulsWidth15))
    hbCommand = HausBusCommand(self.objectId, 209, "evZeroCrossData")
    hbCommand.addByte(channel)
    hbCommand.addByte(pulseCount)
    hbCommand.addByte(deltaTime)
    hbCommand.addWord(lowTime0)
    hbCommand.addWord(lowTime1)
    hbCommand.addWord(lowTime2)
    hbCommand.addWord(lowTime3)
    hbCommand.addWord(lowTime4)
    hbCommand.addWord(lowTime5)
    hbCommand.addWord(lowTime6)
    hbCommand.addWord(lowTime7)
    hbCommand.addWord(lowTime8)
    hbCommand.addWord(lowTime9)
    hbCommand.addWord(lowTime10)
    hbCommand.addWord(lowTime11)
    hbCommand.addWord(lowTime12)
    hbCommand.addWord(lowTime13)
    hbCommand.addWord(lowTime14)
    hbCommand.addWord(lowTime15)
    hbCommand.addWord(pulsWidth0)
    hbCommand.addWord(pulsWidth1)
    hbCommand.addWord(pulsWidth2)
    hbCommand.addWord(pulsWidth3)
    hbCommand.addWord(pulsWidth4)
    hbCommand.addWord(pulsWidth5)
    hbCommand.addWord(pulsWidth6)
    hbCommand.addWord(pulsWidth7)
    hbCommand.addWord(pulsWidth8)
    hbCommand.addWord(pulsWidth9)
    hbCommand.addWord(pulsWidth10)
    hbCommand.addWord(pulsWidth11)
    hbCommand.addWord(pulsWidth12)
    hbCommand.addWord(pulsWidth13)
    hbCommand.addWord(pulsWidth14)
    hbCommand.addWord(pulsWidth15)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param featureId Zusatzfunktion.
  @param key Der Schluessel mit dem die Zusatzfunktion aktiviert werden soll..
  """
  def enableFeature(self, featureId:EFeatureId, key:str):
    LOGGER.debug("enableFeature"+" featureId = "+str(featureId)+" key = "+str(key))
    hbCommand = HausBusCommand(self.objectId, 19, "enableFeature")
    hbCommand.addByte(featureId.value)
    hbCommand.addString(key)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param type Hier wird der Typ der Variable.
  @param index Die Variablen liegen mehrfach vor 32xBIT.
  @param value Die Systemvariable hat nun diesen Wert erhalten..
  """
  def evSystemVariableChanged(self, type:EType, index:int, value:int):
    LOGGER.debug("evSystemVariableChanged"+" type = "+str(type)+" index = "+str(index)+" value = "+str(value))
    hbCommand = HausBusCommand(self.objectId, 210, "evSystemVariableChanged")
    hbCommand.addByte(type.value)
    hbCommand.addByte(index)
    hbCommand.addWord(value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param index 0: loescht alle OneWire Sensor Positionen\r\n1-32: loescht nur den Sensor auf der Position.
  """
  def resetOneWireManager(self, index:int):
    LOGGER.debug("resetOneWireManager"+" index = "+str(index))
    hbCommand = HausBusCommand(self.objectId, 20, "resetOneWireManager")
    hbCommand.addByte(index)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param time Zeit in Sekunden bis zum Reset wenn kein Ping empfangen wird. 0 deativiert den WatchDog.
  """
  def setWatchDogTime(self, time:int):
    LOGGER.debug("setWatchDogTime"+" time = "+str(time))
    hbCommand = HausBusCommand(self.objectId, 21, "setWatchDogTime")
    hbCommand.addWord(time)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils

class Status:
  CLASS_ID = 36
  FUNCTION_ID = 129

  def __init__(self,value:int):
    self.value=value


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Status(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"Status(value={self.value})"

  '''
  @param value .
  '''
  def getValue(self):
    return self.value






import pyhausbus.HausBusUtils as HausBusUtils

class GetConfiguration:
  CLASS_ID = 160
  FUNCTION_ID = 0

  def __init__(self,address0:int, address1:int, address2:int, address3:int):
    self.address0=address0
    self.address1=address1
    self.address2=address2
    self.address3=address3


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetConfiguration(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"GetConfiguration(address0={self.address0}, address1={self.address1}, address2={self.address2}, address3={self.address3})"

  '''
  @param address0 .
  '''
  def getAddress0(self):
    return self.address0

  '''
  @param address1 .
  '''
  def getAddress1(self):
    return self.address1

  '''
  @param address2 .
  '''
  def getAddress2(self):
    return self.address2

  '''
  @param address3 .
  '''
  def getAddress3(self):
    return self.address3






from pyhausbus.WeekTime import WeekTime
import pyhausbus.HausBusUtils as HausBusUtils

class EvTime:
  CLASS_ID = 0
  FUNCTION_ID = 200

  def __init__(self,weektime:WeekTime):
    self.weektime=weektime


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvTime(WeekTime._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvTime(weektime={self.weektime})"

  '''
  @param weektime .
  '''
  def getWeektime(self):
    return self.weektime






from pyhausbus.WeekTime import WeekTime
import pyhausbus.HausBusUtils as HausBusUtils

class SetSunTimes:
  CLASS_ID = 0
  FUNCTION_ID = 15

  def __init__(self,sunriseTime:WeekTime, sunsetTime:WeekTime):
    self.sunriseTime=sunriseTime
    self.sunsetTime=sunsetTime


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetSunTimes(WeekTime._fromBytes(dataIn, offset), WeekTime._fromBytes(dataIn, offset))

  def __str__(self):
    return f"SetSunTimes(sunriseTime={self.sunriseTime}, sunsetTime={self.sunsetTime})"

  '''
  @param sunriseTime Zeit fuer den Sonnenaufgang..
  '''
  def getSunriseTime(self):
    return self.sunriseTime

  '''
  @param sunsetTime Zeit fuer den Sonnenuntergang..
  '''
  def getSunsetTime(self):
    return self.sunsetTime






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ESensorType(Enum):
  NONE=0
  SDM_TOTAL_POWER=1
  SDM_IMPORT_POWER=2
  SDM_EXPORT_POWER=3
  SDM_IMPORT_ENERGY=4
  SDM_EXPORT_ENERGY=5
  ORWE517_TOTAL_POWER=6
  ORWE517_TOTAL_ENERGY=7
  ORWE517_FORWARD_ENERGY=8
  ORWE517_REVERSE_ENERGY=9
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ESensorType.__members__.values():
      if (act.value == checkValue):
        return act

    return ESensorType.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ESensorType':
    try:
      return ESensorType[name]
    except KeyError:
      return ESensorType.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils

class ToggleByDuty:
  CLASS_ID = 19
  FUNCTION_ID = 6

  def __init__(self,duty:int, quantity:int):
    self.duty=duty
    self.quantity=quantity


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return ToggleByDuty(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"ToggleByDuty(duty={self.duty}, quantity={self.quantity})"

  '''
  @param duty 0-100% Pulsverh?ltnis.
  '''
  def getDuty(self):
    return self.duty

  '''
  @param quantity Anzahl der Zustandswechsel.
  '''
  def getQuantity(self):
    return self.quantity






import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 20
  FUNCTION_ID = 1

  def __init__(self,button1:int, button2:int, button3:int, button4:int, button5:int, button6:int, button7:int, button8:int, led1:int, led2:int, led3:int, led4:int, led5:int, led6:int, led7:int, led8:int):
    self.button1=button1
    self.button2=button2
    self.button3=button3
    self.button4=button4
    self.button5=button5
    self.button6=button6
    self.button7=button7
    self.button8=button8
    self.led1=led1
    self.led2=led2
    self.led3=led3
    self.led4=led4
    self.led5=led5
    self.led6=led6
    self.led7=led7
    self.led8=led8


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(button1={self.button1}, button2={self.button2}, button3={self.button3}, button4={self.button4}, button5={self.button5}, button6={self.button6}, button7={self.button7}, button8={self.button8}, led1={self.led1}, led2={self.led2}, led3={self.led3}, led4={self.led4}, led5={self.led5}, led6={self.led6}, led7={self.led7}, led8={self.led8})"

  '''
  @param button1 instanzId des 1.Tasters.
  '''
  def getButton1(self):
    return self.button1

  '''
  @param button2 instanzId des 2.Tasters.
  '''
  def getButton2(self):
    return self.button2

  '''
  @param button3 .
  '''
  def getButton3(self):
    return self.button3

  '''
  @param button4 .
  '''
  def getButton4(self):
    return self.button4

  '''
  @param button5 .
  '''
  def getButton5(self):
    return self.button5

  '''
  @param button6 .
  '''
  def getButton6(self):
    return self.button6

  '''
  @param button7 .
  '''
  def getButton7(self):
    return self.button7

  '''
  @param button8 .
  '''
  def getButton8(self):
    return self.button8

  '''
  @param led1 .
  '''
  def getLed1(self):
    return self.led1

  '''
  @param led2 .
  '''
  def getLed2(self):
    return self.led2

  '''
  @param led3 .
  '''
  def getLed3(self):
    return self.led3

  '''
  @param led4 .
  '''
  def getLed4(self):
    return self.led4

  '''
  @param led5 .
  '''
  def getLed5(self):
    return self.led5

  '''
  @param led6 .
  '''
  def getLed6(self):
    return self.led6

  '''
  @param led7 .
  '''
  def getLed7(self):
    return self.led7

  '''
  @param led8 .
  '''
  def getLed8(self):
    return self.led8






from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.params.EFunction import EFunction
import pyhausbus.HausBusUtils as HausBusUtils

class GenericResponse:
  CLASS_ID = 45
  FUNCTION_ID = 129

  def __init__(self,node:int, function:EFunction, address:int, data:bytearray):
    self.node=node
    self.function=function
    self.address=address
    self.data=data


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GenericResponse(HausBusUtils.bytesToInt(dataIn, offset), EFunction._fromBytes(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToBlob(dataIn, offset))

  def __str__(self):
    return f"GenericResponse(node={self.node}, function={self.function}, address={self.address}, data={self.data})"

  '''
  @param node Bus-Knoten Geraete-Adresse.
  '''
  def getNode(self):
    return self.node

  '''
  @param function Mod-Bus Funktion.
  '''
  def getFunction(self):
    return self.function

  '''
  @param address Adresse in Geraet.
  '''
  def getAddress(self):
    return self.address

  '''
  @param data Daten.
  '''
  def getData(self):
    return self.data






from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.params.EErrorCode import EErrorCode
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.params.EStatus import EStatus
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.data.Status import Status
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.params.MEventMask import MEventMask
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.params.MOptionMask import MOptionMask
from pyhausbus.de.hausbus.homeassistant.proxy.logicalButton.params.MOptions import MOptions

class LogicalButton(ABusFeature):
  CLASS_ID:int = 20

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return LogicalButton(HausBusUtils.getObjectId(deviceId, 20, instanceId))

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param button1 instanzId des 1.Tasters.
  @param button2 instanzId des 2.Tasters.
  @param button3 .
  @param button4 .
  @param button5 .
  @param button6 .
  @param button7 .
  @param button8 .
  @param led1 .
  @param led2 .
  @param led3 .
  @param led4 .
  @param led5 .
  @param led6 .
  @param led7 .
  @param led8 .
  """
  def setConfiguration(self, button1:int, button2:int, button3:int, button4:int, button5:int, button6:int, button7:int, button8:int, led1:int, led2:int, led3:int, led4:int, led5:int, led6:int, led7:int, led8:int):
    LOGGER.debug("setConfiguration"+" button1 = "+str(button1)+" button2 = "+str(button2)+" button3 = "+str(button3)+" button4 = "+str(button4)+" button5 = "+str(button5)+" button6 = "+str(button6)+" button7 = "+str(button7)+" button8 = "+str(button8)+" led1 = "+str(led1)+" led2 = "+str(led2)+" led3 = "+str(led3)+" led4 = "+str(led4)+" led5 = "+str(led5)+" led6 = "+str(led6)+" led7 = "+str(led7)+" led8 = "+str(led8))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(button1)
    hbCommand.addByte(button2)
    hbCommand.addByte(button3)
    hbCommand.addByte(button4)
    hbCommand.addByte(button5)
    hbCommand.addByte(button6)
    hbCommand.addByte(button7)
    hbCommand.addByte(button8)
    hbCommand.addByte(led1)
    hbCommand.addByte(led2)
    hbCommand.addByte(led3)
    hbCommand.addByte(led4)
    hbCommand.addByte(led5)
    hbCommand.addByte(led6)
    hbCommand.addByte(led7)
    hbCommand.addByte(led8)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param button1 .
  @param button2 .
  @param button3 .
  @param button4 .
  @param button5 .
  @param button6 .
  @param button7 .
  @param button8 .
  @param led1 .
  @param led2 .
  @param led3 .
  @param led4 .
  @param led5 .
  @param led6 .
  @param led7 .
  @param led8 .
  """
  def Configuration(self, button1:int, button2:int, button3:int, button4:int, button5:int, button6:int, button7:int, button8:int, led1:int, led2:int, led3:int, led4:int, led5:int, led6:int, led7:int, led8:int):
    LOGGER.debug("Configuration"+" button1 = "+str(button1)+" button2 = "+str(button2)+" button3 = "+str(button3)+" button4 = "+str(button4)+" button5 = "+str(button5)+" button6 = "+str(button6)+" button7 = "+str(button7)+" button8 = "+str(button8)+" led1 = "+str(led1)+" led2 = "+str(led2)+" led3 = "+str(led3)+" led4 = "+str(led4)+" led5 = "+str(led5)+" led6 = "+str(led6)+" led7 = "+str(led7)+" led8 = "+str(led8))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(button1)
    hbCommand.addByte(button2)
    hbCommand.addByte(button3)
    hbCommand.addByte(button4)
    hbCommand.addByte(button5)
    hbCommand.addByte(button6)
    hbCommand.addByte(button7)
    hbCommand.addByte(button8)
    hbCommand.addByte(led1)
    hbCommand.addByte(led2)
    hbCommand.addByte(led3)
    hbCommand.addByte(led4)
    hbCommand.addByte(led5)
    hbCommand.addByte(led6)
    hbCommand.addByte(led7)
    hbCommand.addByte(led8)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evOff(self):
    LOGGER.debug("evOff")
    hbCommand = HausBusCommand(self.objectId, 200, "evOff")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightness 0-100% Helligkeit.
  """
  def evOn(self, brightness:int):
    LOGGER.debug("evOn"+" brightness = "+str(brightness))
    hbCommand = HausBusCommand(self.objectId, 201, "evOn")
    hbCommand.addByte(brightness)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evBlink(self):
    LOGGER.debug("evBlink")
    hbCommand = HausBusCommand(self.objectId, 202, "evBlink")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param offDelay Ausschaltverzoegerung: Wert * Zeitbasis [ms]\r\n0=Keine.
  """
  def off(self, offDelay:int):
    LOGGER.debug("off"+" offDelay = "+str(offDelay))
    hbCommand = HausBusCommand(self.objectId, 2, "off")
    hbCommand.addWord(offDelay)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightness 0-100% Helligkeit.
  @param duration Einschaltdauer in Sekunden.
  @param onDelay Einschaltverzoegerung: Wert * Zeitbasis [ms]\r\n0=Keine.
  """
  def on(self, brightness:int, duration:int, onDelay:int):
    LOGGER.debug("on"+" brightness = "+str(brightness)+" duration = "+str(duration)+" onDelay = "+str(onDelay))
    hbCommand = HausBusCommand(self.objectId, 3, "on")
    hbCommand.addByte(brightness)
    hbCommand.addWord(duration)
    hbCommand.addWord(onDelay)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightness 0-100% Helligkeit.
  @param offTime a 100ms.
  @param onTime a 100ms.
  @param quantity Anzahl Blinks.
  """
  def blink(self, brightness:int, offTime:int, onTime:int, quantity:int):
    LOGGER.debug("blink"+" brightness = "+str(brightness)+" offTime = "+str(offTime)+" onTime = "+str(onTime)+" quantity = "+str(quantity))
    hbCommand = HausBusCommand(self.objectId, 4, "blink")
    hbCommand.addByte(brightness)
    hbCommand.addByte(offTime)
    hbCommand.addByte(onTime)
    hbCommand.addByte(quantity)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param status Zustand der Taster LEDs.
  """
  def Status(self, status:EStatus):
    LOGGER.debug("Status"+" status = "+str(status))
    hbCommand = HausBusCommand(self.objectId, 129, "Status")
    hbCommand.addByte(status.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getStatus(self):
    LOGGER.debug("getStatus")
    hbCommand = HausBusCommand(self.objectId, 5, "getStatus")
    ResultWorker()._setResultInfo(Status,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param holdTimeout Zeit a 10ms.
  @param waitForDoubleClickTimeout Zeit a 10ms.
  @param eventMask Jedes gesetzte Bit aktiviert das Melden des entsprechenden Events..
  @param optionMask 0: invertiert die Eingangslogik\r\n1: setzt den Initialzustand auf 0.
  """
  def setButtonConfiguration(self, holdTimeout:int, waitForDoubleClickTimeout:int, eventMask:MEventMask, optionMask:MOptionMask):
    LOGGER.debug("setButtonConfiguration"+" holdTimeout = "+str(holdTimeout)+" waitForDoubleClickTimeout = "+str(waitForDoubleClickTimeout)+" eventMask = "+str(eventMask)+" optionMask = "+str(optionMask))
    hbCommand = HausBusCommand(self.objectId, 11, "setButtonConfiguration")
    hbCommand.addByte(holdTimeout)
    hbCommand.addByte(waitForDoubleClickTimeout)
    hbCommand.addByte(eventMask.getValue())
    hbCommand.addByte(optionMask.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param dimmOffset 0-100% offset auf den im Kommando angegebenen Helligkeitswert.
  @param minBrightness Eine ausgeschaltete LED leuchtet immer noch mit dieser Helligkeit 0-100%.
  @param timeBase Zeitbasis [ms] fuer Zeitabhaengige Befehle..
  @param options eservierte Bits muessen immer deaktiviert sein. Das Aktivieren eines reservierten Bits fuehrt nach dem Neustart des Controllers zu den Standard-Einstellungen..
  """
  def setLedConfiguration(self, dimmOffset:int, minBrightness:int, timeBase:int, options:MOptions):
    LOGGER.debug("setLedConfiguration"+" dimmOffset = "+str(dimmOffset)+" minBrightness = "+str(minBrightness)+" timeBase = "+str(timeBase)+" options = "+str(options))
    hbCommand = HausBusCommand(self.objectId, 12, "setLedConfiguration")
    hbCommand.addByte(dimmOffset)
    hbCommand.addByte(minBrightness)
    hbCommand.addWord(timeBase)
    hbCommand.addByte(options.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param minBrightness Eine ausgeschaltete LED leuchtet immer noch mit dieser Helligkeit 0-100%.
  """
  def setMinBrightness(self, minBrightness:int):
    LOGGER.debug("setMinBrightness"+" minBrightness = "+str(minBrightness))
    hbCommand = HausBusCommand(self.objectId, 6, "setMinBrightness")
    hbCommand.addByte(minBrightness)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getMinBrightness(self):
    LOGGER.debug("getMinBrightness")
    hbCommand = HausBusCommand(self.objectId, 7, "getMinBrightness")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")






class GenericBusData:

  def __init__(self):
    pass  # Platzhalter, sonst IndentationError
    
  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GenericBusData()

  def __str__(self):
    return f"GenericBusData()"





import pyhausbus.HausBusUtils as HausBusUtils

class RemoteObjects:
  CLASS_ID = 0
  FUNCTION_ID = 129

  def __init__(self,objectList):
    self.objectList=objectList


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return RemoteObjects(HausBusUtils.bytesToList(dataIn, offset))

  def __str__(self):
    return f"RemoteObjects(objectList={self.objectList})"

  '''
  @param objectList Eine Liste der Verfuegbaren Objekte im Geraete.
  '''
  def getObjectList(self):
    return self.objectList






import pyhausbus.HausBusUtils as HausBusUtils

class WakeUpDevice:
  CLASS_ID = 164
  FUNCTION_ID = 2

  def __init__(self,mac1:int, mac2:int, mac3:int, mac4:int, mac5:int, mac6:int):
    self.mac1=mac1
    self.mac2=mac2
    self.mac3=mac3
    self.mac4=mac4
    self.mac5=mac5
    self.mac6=mac6


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return WakeUpDevice(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"WakeUpDevice(mac1={self.mac1}, mac2={self.mac2}, mac3={self.mac3}, mac4={self.mac4}, mac5={self.mac5}, mac6={self.mac6})"

  '''
  @param mac1 .
  '''
  def getMac1(self):
    return self.mac1

  '''
  @param mac2 .
  '''
  def getMac2(self):
    return self.mac2

  '''
  @param mac3 .
  '''
  def getMac3(self):
    return self.mac3

  '''
  @param mac4 .
  '''
  def getMac4(self):
    return self.mac4

  '''
  @param mac5 .
  '''
  def getMac5(self):
    return self.mac5

  '''
  @param mac6 .
  '''
  def getMac6(self):
    return self.mac6






import pyhausbus.HausBusUtils as HausBusUtils
class MConfig:

  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MConfig(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    return result
  def setEntry(self,name:str, setValue:bool):

  def __str__(self):
    return f"MConfig()"



